@@ -265,7 +265,8 @@ ClockClassRec clockClassRec = {
      /* extension                */ NULL
      },
     {                           /* simple fields */
-     /* change_sensitive         */ XtInheritChangeSensitive
+     /* change_sensitive         */ XtInheritChangeSensitive,
+     /* extension                */ NULL
      },
     {                           /* clock fields */
      /* ignore                   */ 0
@@ -1734,7 +1735,14 @@ erase_hands(ClockWidget w, struct tm *tm)
 static void
 ClockAngle(double tick_units, double *sinp, double *cosp)
 {
-    sincos(tick_units * (M_PI / 180 / 10.0), sinp, cosp);
+    double angle = tick_units * (M_PI / 180 / 10.0);
+
+#ifdef HAVE_SINCOS
+    sincos(angle, sinp, cosp);
+#else
+    *sinp = sin(angle);
+    *cosp = cos(angle);
+#endif
 }
 
 /*
@@ -2008,7 +2016,7 @@ SetValues(Widget gcurrent, Widget grequest, Widget gnew,
                                 (XtPointer) gnew);
 
         new->clock.show_second_hand =
-            (abs(new->clock.update) <= SECOND_HAND_TIME);
+            (fabsf(new->clock.update) <= SECOND_HAND_TIME);
         if (new->clock.show_second_hand != current->clock.show_second_hand)
             redisplay = TRUE;
     }
